package fr.eni.enchere.dal;

import fr.eni.enchere.bo.UserProfil;

import java.util.List;

public interface UserRepository {
    List<UserProfil> findAll();
    UserProfil findById(int id);
    UserProfil findByUsername(String username);
    UserProfil findUserByEmail(String email);
    List<String> findAllUsernames();
    List<String> findAllEmail();
    String findByEmail(String email);
    void save(UserProfil utilisateur);
    void updateCredit(float credit, int id);
    void delete(int id);
    void disable(int id);
    void enable(int id);
    void onAdmin(int id);
    void offAdmin(int id);
}
